@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of LHAPDF
-// Copyright (C) 2012-2016 The LHAPDF collaboration (see AUTHORS for details)
+// Copyright (C) 2012-2021 The LHAPDF collaboration (see AUTHORS for details)
 //
 #pragma once
 #ifndef LHAPDF_LogBicubicInterpolator_H
@@ -16,10 +16,18 @@ namespace LHAPDF {
   ///
   /// This class will interpolate in 2D using a bicubic hermite spline.
   class LogBicubicInterpolator : public Interpolator {
+    
   public:
-    double _interpolateXQ2(const KnotArray1F& subgrid, double x, size_t ix, double q2, size_t iq2) const;
+    LogBicubicInterpolator(){ setType("logcubic"); }
+    
+    /// Implementation of (x,Q2) interpolation
+    double _interpolateXQ2(const KnotArray& subgrid, double x, size_t ix, double q2, size_t iq2, int id) const;
+
+    void _interpolateXQ2(const KnotArray& subgrid, double x, size_t ix, double q2, size_t iq2, std::vector<double>& ret) const;
+
+    
   };
 
-
 }
+
 #endif
